@@ -13,10 +13,10 @@
 # limitations under the License.
 
 import copy
-from gz_test_deps.sdformat import (Element, Error, Geometry, Box, Capsule, Cone, Cylinder, Ellipsoid,
-                                   Heightmap, Mesh, ParserConfig, Plane, Sphere)
-from gz_test_deps.math import AxisAlignedBox, Inertiald, MassMatrix3d, Pose3d, Vector3d, Vector2d
-import gz_test_deps.sdformat as sdf
+from sdformat import (Element, Error, Geometry, Box, Capsule, Cone, Cylinder, Ellipsoid,
+                      Heightmap, Mesh, ParserConfig, Plane, Sphere)
+from gz.math import AxisAlignedBox, Inertiald, MassMatrix3d, Pose3d, Vector3d, Vector2d
+import sdformat as sdf
 import math
 from typing import Optional
 import unittest
