@@ -20,6 +20,7 @@
 #include <gz/math/Material.hh>
 #include <gz/math/MassMatrix3.hh>
 #include <gz/math/Inertial.hh>
+#include "sdf/Console.hh"
 #include "sdf/Box.hh"
 #include "sdf/parser.hh"
 #include "Utils.hh"
@@ -75,10 +76,19 @@ Errors Box::Load(ElementPtr _sdf)
     if (!pair.second)
     {
       errors.push_back({ErrorCode::ELEMENT_INVALID,
-          "Invalid <size> data for a <box> geometry. "
-          "Using a size of 1, 1, 1 "});
+          "Invalid <size> data for a <box> geometry."});
+    }
+    else
+    {
+      if (pair.first.X() <= 0 || pair.first.Y() <= 0 ||
+          pair.first.Z() <= 0)
+      {
+        sdfwarn << "Value of <size> is negative. "
+            << "Using default value of 1, 1, 1.\n";
+        pair.first = gz::math::Vector3d::One;
+      }
+      this->dataPtr->box.SetSize(pair.first);
     }
-    this->dataPtr->box.SetSize(pair.first);
   }
   else
   {
