@@ -22,7 +22,7 @@
 #include "sdf/Link.hh"
 #include "sdf/Model.hh"
 #include "sdf/parser.hh"
-#include "test_config.h"
+#include "test_config.hh"
 
 /////////////////////////////////////////////////
 /// Test default construction of sdf::Model.
@@ -128,8 +128,8 @@ TEST(DOMModel, Construction)
     EXPECT_FALSE(semanticPose.Resolve(pose).empty());
   }
 
-  model.SetRawPose({1, 2, 3, 0, 0, IGN_PI});
-  EXPECT_EQ(gz::math::Pose3d(1, 2, 3, 0, 0, IGN_PI), model.RawPose());
+  model.SetRawPose({1, 2, 3, 0, 0, GZ_PI});
+  EXPECT_EQ(gz::math::Pose3d(1, 2, 3, 0, 0, GZ_PI), model.RawPose());
 
   model.SetPoseRelativeTo("world");
   EXPECT_EQ("world", model.PoseRelativeTo());
@@ -154,6 +154,10 @@ TEST(DOMModel, Construction)
     errors[1].Message().find(
       "PoseRelativeToGraph error: scope does not point to a valid graph"))
       << errors[1];
+
+  // model doesn't have graphs, so no names should exist in graphs
+  EXPECT_FALSE(model.NameExistsInFrameAttachedToGraph(""));
+  EXPECT_FALSE(model.NameExistsInFrameAttachedToGraph("link"));
 }
 
 /////////////////////////////////////////////////
@@ -229,6 +233,9 @@ TEST(DOMModel, AddLink)
   EXPECT_EQ(1u, model.LinkCount());
   EXPECT_FALSE(model.AddLink(link));
   EXPECT_EQ(1u, model.LinkCount());
+  // model doesn't have graphs, so no names should exist in graphs
+  EXPECT_FALSE(model.NameExistsInFrameAttachedToGraph(""));
+  EXPECT_FALSE(model.NameExistsInFrameAttachedToGraph("link1"));
 
   model.ClearLinks();
   EXPECT_EQ(0u, model.LinkCount());
@@ -332,6 +339,16 @@ TEST(DOMModel, ToElement)
   model.SetEnableWind(true);
   model.SetRawPose(gz::math::Pose3d(1, 2, 3, 0.1, 0.2, 0.3));
 
+  sdf::Frame frame1, frame2;
+  frame1.SetName("my-frame1");
+  frame1.SetRawPose(gz::math::Pose3d(1, 2, 3, 0.1, 0.2, 0.3));
+  model.AddFrame(frame1);
+  frame2.SetName("my-frame2");
+  frame2.SetAttachedTo("my-frame1");
+  frame2.SetRawPose(gz::math::Pose3d(-1, 20, 34, 0.1, 0.2, 0.3));
+  model.AddFrame(frame2);
+  EXPECT_EQ(2u, model.FrameCount());
+
   for (int j = 0; j <= 1; ++j)
   {
     for (int i = 0; i < 1; ++i)
@@ -408,6 +425,17 @@ TEST(DOMModel, ToElement)
   ASSERT_EQ(1u, model2.Plugins().size());
   EXPECT_EQ("name1", model2.Plugins()[0].Name());
   EXPECT_EQ("filename1", model2.Plugins()[0].Filename());
+
+  ASSERT_EQ(2u, model2.FrameCount());
+  const sdf::Frame *model2Frame1 = model2.FrameByIndex(0);
+  EXPECT_EQ(frame1.Name(), model2Frame1->Name());
+  EXPECT_EQ(frame1.AttachedTo(), model2Frame1->AttachedTo());
+  EXPECT_EQ(frame1.RawPose(), model2Frame1->RawPose());
+
+  const sdf::Frame *model2Frame2 = model2.FrameByIndex(1);
+  EXPECT_EQ(frame2.Name(), model2Frame2->Name());
+  EXPECT_EQ(frame2.AttachedTo(), model2Frame2->AttachedTo());
+  EXPECT_EQ(frame2.RawPose(), model2Frame2->RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -417,7 +445,7 @@ TEST(DOMModel, Uri)
   std::string name = "my-model";
   gz::math::Pose3d pose(1, 2, 3, 0.1, 0.2, 0.3);
   std::string uri =
-    "https://fuel.ignitionrobotics.org/1.0/openrobotics/models/my-model";
+    "https://fuel.gazebosim.org/1.0/openrobotics/models/my-model";
 
   model.SetName(name);
   model.SetRawPose(pose);
