@@ -17,6 +17,7 @@
 
 #include <gtest/gtest.h>
 #include "sdf/Polyline.hh"
+#include "test_utils.hh"
 
 /////////////////////////////////////////////////
 TEST(DOMPolyline, Construction)
@@ -113,9 +114,12 @@ TEST(DOMPolyline, Load)
   // Missing <height> element
   sdf->SetName("polyline");
   errors = polyline.Load(sdf);
-  ASSERT_EQ(1u, errors.size());
+  ASSERT_EQ(2u, errors.size());
   EXPECT_EQ(sdf::ErrorCode::ELEMENT_MISSING, errors[0].Code());
   EXPECT_NE(std::string::npos, errors[0].Message().find("missing a <height>"));
+  EXPECT_EQ(sdf::ErrorCode::ELEMENT_ERROR, errors[1].Code());
+  EXPECT_NE(std::string::npos, errors[1].Message().find(
+      "Missing element description for [point]"));
   EXPECT_NE(nullptr, polyline.Element());
 }
 
@@ -174,3 +178,46 @@ TEST(DOMPolyline, ToElement)
   EXPECT_EQ(*polyline.PointByIndex(0), *polyline2.PointByIndex(0));
   EXPECT_EQ(*polyline.PointByIndex(1), *polyline2.PointByIndex(1));
 }
+
+/////////////////////////////////////////////////
+TEST(DOMPolyline, ToElementErrorOutput)
+{
+  std::stringstream buffer;
+  sdf::testing::RedirectConsoleStream redir(
+      sdf::Console::Instance()->GetMsgStream(), &buffer);
+
+  #ifdef _WIN32
+    sdf::Console::Instance()->SetQuiet(false);
+    sdf::testing::ScopeExit revertSetQuiet(
+      []
+      {
+        sdf::Console::Instance()->SetQuiet(true);
+      });
+  #endif
+
+  sdf::Polyline polyline;
+  sdf::Errors errors;
+  polyline.SetHeight(1.2);
+
+  gz::math::Vector2d p1{1, 2};
+  gz::math::Vector2d p2{3, 4};
+  EXPECT_TRUE(polyline.AddPoint(p1));
+  EXPECT_TRUE(polyline.AddPoint(p2));
+
+  auto elem = polyline.ToElement(errors);
+  EXPECT_TRUE(errors.empty());
+  ASSERT_NE(nullptr, elem);
+
+  sdf::Polyline polyline2;
+  errors = polyline2.Load(elem);
+  EXPECT_TRUE(errors.empty());
+
+  EXPECT_DOUBLE_EQ(polyline.Height(), polyline2.Height());
+  ASSERT_EQ(polyline.PointCount(), polyline2.PointCount());
+
+  EXPECT_EQ(*polyline.PointByIndex(0), *polyline2.PointByIndex(0));
+  EXPECT_EQ(*polyline.PointByIndex(1), *polyline2.PointByIndex(1));
+
+  // Check nothing has been printed
+  EXPECT_TRUE(buffer.str().empty()) << buffer.str();
+}
