@@ -1,13 +1,13 @@
 /*********************************************************************
 * Software Ligcense Agreement (BSD License)
-* 
+*
 *  Copyright (c) 2008, Willow Garage, Inc.
 *  All rights reserved.
-* 
+*
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
-* 
+*
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
@@ -17,7 +17,7 @@
 *   * Neither the name of the Willow Garage nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
-* 
+*
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
@@ -33,37 +33,41 @@
 *********************************************************************/
 
 /* Author: John Hsu */
+#pragma warning(push, 0)
 
 #include <sstream>
+#include <stdexcept>
+#include <string>
 #include <urdf_model/joint.h>
-#include <boost/lexical_cast.hpp>
-//#include <console_bridge/console.h>
-#include <tinyxml.h>
-#include <urdf_parser/urdf_parser.h>
+// #include <console_bridge/console.h>
+#include <tinyxml2.h>
+#include "../urdf_parser/urdf_parser.h"
 
 namespace urdf{
 
-bool parsePose(Pose &pose, TiXmlElement* xml);
+bool parsePose(Pose &pose, tinyxml2::XMLElement* xml);
 
-bool parseJointDynamics(JointDynamics &jd, TiXmlElement* config)
+bool parseJointDynamics(JointDynamics &jd, tinyxml2::XMLElement* config)
 {
   jd.clear();
 
   // Get joint damping
   const char* damping_str = config->Attribute("damping");
   if (damping_str == NULL){
-    //logDebug("joint dynamics: no damping, defaults to 0");
     jd.damping = 0;
   }
   else
   {
     try
     {
-      jd.damping = boost::lexical_cast<double>(damping_str);
+      jd.damping = std::stod(damping_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("damping value (%s) is not a float: %s",damping_str, e.what());
       return false;
     }
   }
@@ -71,52 +75,54 @@ bool parseJointDynamics(JointDynamics &jd, TiXmlElement* config)
   // Get joint friction
   const char* friction_str = config->Attribute("friction");
   if (friction_str == NULL){
-    //logDebug("joint dynamics: no friction, defaults to 0");
     jd.friction = 0;
   }
   else
   {
     try
     {
-      jd.friction = boost::lexical_cast<double>(friction_str);
+      jd.friction = std::stod(friction_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("friction value (%s) is not a float: %s",friction_str, e.what());
       return false;
     }
   }
 
   if (damping_str == NULL && friction_str == NULL)
   {
-    //logError("joint dynamics element specified with no damping and no friction");
     return false;
   }
   else{
-    //logDebug("joint dynamics: damping %f and friction %f", jd.damping, jd.friction);
     return true;
   }
 }
 
-bool parseJointLimits(JointLimits &jl, TiXmlElement* config)
+bool parseJointLimits(JointLimits &jl, tinyxml2::XMLElement* config)
 {
   jl.clear();
 
   // Get lower joint limit
   const char* lower_str = config->Attribute("lower");
   if (lower_str == NULL){
-    //logDebug("joint limit: no lower, defaults to 0");
     jl.lower = 0;
   }
   else
   {
     try
     {
-      jl.lower = boost::lexical_cast<double>(lower_str);
+      jl.lower = std::stod(lower_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("lower value (%s) is not a float: %s", lower_str, e.what());
       return false;
     }
   }
@@ -124,18 +130,20 @@ bool parseJointLimits(JointLimits &jl, TiXmlElement* config)
   // Get upper joint limit
   const char* upper_str = config->Attribute("upper");
   if (upper_str == NULL){
-    //logDebug("joint limit: no upper, , defaults to 0");
     jl.upper = 0;
   }
   else
   {
     try
     {
-      jl.upper = boost::lexical_cast<double>(upper_str);
+      jl.upper = std::stod(upper_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("upper value (%s) is not a float: %s",upper_str, e.what());
       return false;
     }
   }
@@ -143,18 +151,20 @@ bool parseJointLimits(JointLimits &jl, TiXmlElement* config)
   // Get joint effort limit
   const char* effort_str = config->Attribute("effort");
   if (effort_str == NULL){
-    //logError("joint limit: no effort");
     return false;
   }
   else
   {
     try
     {
-      jl.effort = boost::lexical_cast<double>(effort_str);
+      jl.effort = std::stod(effort_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("effort value (%s) is not a float: %s",effort_str, e.what());
       return false;
     }
   }
@@ -162,18 +172,20 @@ bool parseJointLimits(JointLimits &jl, TiXmlElement* config)
   // Get joint velocity limit
   const char* velocity_str = config->Attribute("velocity");
   if (velocity_str == NULL){
-    //logError("joint limit: no velocity");
     return false;
   }
   else
   {
     try
     {
-      jl.velocity = boost::lexical_cast<double>(velocity_str);
+      jl.velocity = std::stod(velocity_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("velocity value (%s) is not a float: %s",velocity_str, e.what());
       return false;
     }
   }
@@ -181,7 +193,7 @@ bool parseJointLimits(JointLimits &jl, TiXmlElement* config)
   return true;
 }
 
-bool parseJointSafety(JointSafety &js, TiXmlElement* config)
+bool parseJointSafety(JointSafety &js, tinyxml2::XMLElement* config)
 {
   js.clear();
 
@@ -189,18 +201,20 @@ bool parseJointSafety(JointSafety &js, TiXmlElement* config)
   const char* soft_lower_limit_str = config->Attribute("soft_lower_limit");
   if (soft_lower_limit_str == NULL)
   {
-    //logDebug("joint safety: no soft_lower_limit, using default value");
     js.soft_lower_limit = 0;
   }
   else
   {
     try
     {
-      js.soft_lower_limit = boost::lexical_cast<double>(soft_lower_limit_str);
+      js.soft_lower_limit = std::stod(soft_lower_limit_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("soft_lower_limit value (%s) is not a float: %s",soft_lower_limit_str, e.what());
       return false;
     }
   }
@@ -209,18 +223,20 @@ bool parseJointSafety(JointSafety &js, TiXmlElement* config)
   const char* soft_upper_limit_str = config->Attribute("soft_upper_limit");
   if (soft_upper_limit_str == NULL)
   {
-    //logDebug("joint safety: no soft_upper_limit, using default value");
     js.soft_upper_limit = 0;
   }
   else
   {
     try
     {
-      js.soft_upper_limit = boost::lexical_cast<double>(soft_upper_limit_str);
+      js.soft_upper_limit = std::stod(soft_upper_limit_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("soft_upper_limit value (%s) is not a float: %s",soft_upper_limit_str, e.what());
       return false;
     }
   }
@@ -229,18 +245,20 @@ bool parseJointSafety(JointSafety &js, TiXmlElement* config)
   const char* k_position_str = config->Attribute("k_position");
   if (k_position_str == NULL)
   {
-    //logDebug("joint safety: no k_position, using default value");
     js.k_position = 0;
   }
   else
   {
     try
     {
-      js.k_position = boost::lexical_cast<double>(k_position_str);
+      js.k_position = std::stod(k_position_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("k_position value (%s) is not a float: %s",k_position_str, e.what());
       return false;
     }
   }
@@ -248,18 +266,20 @@ bool parseJointSafety(JointSafety &js, TiXmlElement* config)
   const char* k_velocity_str = config->Attribute("k_velocity");
   if (k_velocity_str == NULL)
   {
-    //logError("joint safety: no k_velocity");
     return false;
   }
   else
   {
     try
     {
-      js.k_velocity = boost::lexical_cast<double>(k_velocity_str);
+      js.k_velocity = std::stod(k_velocity_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("k_velocity value (%s) is not a float: %s",k_velocity_str, e.what());
       return false;
     }
   }
@@ -267,7 +287,7 @@ bool parseJointSafety(JointSafety &js, TiXmlElement* config)
   return true;
 }
 
-bool parseJointCalibration(JointCalibration &jc, TiXmlElement* config)
+bool parseJointCalibration(JointCalibration &jc, tinyxml2::XMLElement* config)
 {
   jc.clear();
 
@@ -275,18 +295,20 @@ bool parseJointCalibration(JointCalibration &jc, TiXmlElement* config)
   const char* rising_position_str = config->Attribute("rising");
   if (rising_position_str == NULL)
   {
-    //logDebug("joint calibration: no rising, using default value");
     jc.rising.reset();
   }
   else
   {
     try
     {
-      jc.rising.reset(new double(boost::lexical_cast<double>(rising_position_str)));
+      jc.rising.reset(new double(std::stod(rising_position_str)));
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("risingvalue (%s) is not a float: %s",rising_position_str, e.what());
       return false;
     }
   }
@@ -295,18 +317,20 @@ bool parseJointCalibration(JointCalibration &jc, TiXmlElement* config)
   const char* falling_position_str = config->Attribute("falling");
   if (falling_position_str == NULL)
   {
-    //logDebug("joint calibration: no falling, using default value");
     jc.falling.reset();
   }
   else
   {
     try
     {
-      jc.falling.reset(new double(boost::lexical_cast<double>(falling_position_str)));
+      jc.falling.reset(new double(std::stod(falling_position_str)));
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("fallingvalue (%s) is not a float: %s",falling_position_str, e.what());
       return false;
     }
   }
@@ -314,7 +338,7 @@ bool parseJointCalibration(JointCalibration &jc, TiXmlElement* config)
   return true;
 }
 
-bool parseJointMimic(JointMimic &jm, TiXmlElement* config)
+bool parseJointMimic(JointMimic &jm, tinyxml2::XMLElement* config)
 {
   jm.clear();
 
@@ -323,50 +347,53 @@ bool parseJointMimic(JointMimic &jm, TiXmlElement* config)
 
   if (joint_name_str == NULL)
   {
-    //logError("joint mimic: no mimic joint specified");
     return false;
   }
   else
     jm.joint_name = joint_name_str;
-  
+
   // Get mimic multiplier
   const char* multiplier_str = config->Attribute("multiplier");
 
   if (multiplier_str == NULL)
   {
-    //logDebug("joint mimic: no multiplier, using default value of 1");
-    jm.multiplier = 1;    
+    jm.multiplier = 1;
   }
   else
   {
     try
     {
-      jm.multiplier = boost::lexical_cast<double>(multiplier_str);
+      jm.multiplier = std::stod(multiplier_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("multiplier value (%s) is not a float: %s",multiplier_str, e.what());
       return false;
     }
   }
 
-  
+
   // Get mimic offset
   const char* offset_str = config->Attribute("offset");
   if (offset_str == NULL)
   {
-    //logDebug("joint mimic: no offset, using default value of 0");
     jm.offset = 0;
   }
   else
   {
     try
     {
-      jm.offset = boost::lexical_cast<double>(offset_str);
+      jm.offset = std::stod(offset_str);
     }
-    catch (boost::bad_lexical_cast &e)
+    catch (std::invalid_argument &e)
+    {
+      return false;
+    }
+    catch (std::out_of_range &e)
     {
-      //logError("offset value (%s) is not a float: %s",offset_str, e.what());
       return false;
     }
   }
@@ -374,7 +401,7 @@ bool parseJointMimic(JointMimic &jm, TiXmlElement* config)
   return true;
 }
 
-bool parseJoint(Joint &joint, TiXmlElement* config)
+bool parseJoint(Joint &joint, tinyxml2::XMLElement* config)
 {
   joint.clear();
 
@@ -382,16 +409,14 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
   const char *name = config->Attribute("name");
   if (!name)
   {
-    //logError("unnamed joint found");
     return false;
   }
   joint.name = name;
 
   // Get transform from Parent Link to Joint Frame
-  TiXmlElement *origin_xml = config->FirstChildElement("origin");
+  tinyxml2::XMLElement *origin_xml = config->FirstChildElement("origin");
   if (!origin_xml)
   {
-    //logDebug("Joint [%s] missing origin tag under parent describing transform from Parent Link to Joint Frame, (using Identity transform).", joint.name.c_str());
     joint.parent_to_joint_origin_transform.clear();
   }
   else
@@ -399,19 +424,17 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
     if (!parsePose(joint.parent_to_joint_origin_transform, origin_xml))
     {
       joint.parent_to_joint_origin_transform.clear();
-      //logError("Malformed parent origin element for joint [%s]", joint.name.c_str());
       return false;
     }
   }
 
   // Get Parent Link
-  TiXmlElement *parent_xml = config->FirstChildElement("parent");
+  tinyxml2::XMLElement *parent_xml = config->FirstChildElement("parent");
   if (parent_xml)
   {
     const char *pname = parent_xml->Attribute("link");
     if (!pname)
     {
-      //logInform("no parent link name specified for Joint link [%s]. this might be the root?", joint.name.c_str());
     }
     else
     {
@@ -420,13 +443,12 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
   }
 
   // Get Child Link
-  TiXmlElement *child_xml = config->FirstChildElement("child");
+  tinyxml2::XMLElement *child_xml = config->FirstChildElement("child");
   if (child_xml)
   {
     const char *pname = child_xml->Attribute("link");
     if (!pname)
     {
-      //logInform("no child link name specified for Joint link [%s].", joint.name.c_str());
     }
     else
     {
@@ -438,10 +460,9 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
   const char* type_char = config->Attribute("type");
   if (!type_char)
   {
-    //logError("joint [%s] has no type, check to see if it's a reference.", joint.name.c_str());
     return false;
   }
-  
+
   std::string type_str = type_char;
   if (type_str == "planar")
     joint.type = Joint::PLANAR;
@@ -457,7 +478,6 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
     joint.type = Joint::FIXED;
   else
   {
-    //logError("Joint [%s] has no known type [%s]", joint.name.c_str(), type_str.c_str());
     return false;
   }
 
@@ -465,9 +485,8 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
   if (joint.type != Joint::FLOATING && joint.type != Joint::FIXED)
   {
     // axis
-    TiXmlElement *axis_xml = config->FirstChildElement("axis");
+    tinyxml2::XMLElement *axis_xml = config->FirstChildElement("axis");
     if (!axis_xml){
-      //logDebug("no axis elemement for Joint link [%s], defaulting to (1,0,0) axis", joint.name.c_str());
       joint.axis = Vector3(1.0, 0.0, 0.0);
     }
     else{
@@ -477,7 +496,6 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
         }
         catch (ParseError &e) {
           joint.axis.clear();
-          //logError("Malformed axis element for joint [%s]: %s", joint.name.c_str(), e.what());
           return false;
         }
       }
@@ -485,75 +503,68 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
   }
 
   // Get limit
-  TiXmlElement *limit_xml = config->FirstChildElement("limit");
+  tinyxml2::XMLElement *limit_xml = config->FirstChildElement("limit");
   if (limit_xml)
   {
     joint.limits.reset(new JointLimits());
     if (!parseJointLimits(*joint.limits, limit_xml))
     {
-      //logError("Could not parse limit element for joint [%s]", joint.name.c_str());
       joint.limits.reset();
       return false;
     }
   }
   else if (joint.type == Joint::REVOLUTE)
   {
-    //logError("Joint [%s] is of type REVOLUTE but it does not specify limits", joint.name.c_str());
     return false;
   }
   else if (joint.type == Joint::PRISMATIC)
   {
-    //logError("Joint [%s] is of type PRISMATIC without limits", joint.name.c_str()); 
     return false;
   }
 
   // Get safety
-  TiXmlElement *safety_xml = config->FirstChildElement("safety_controller");
+  tinyxml2::XMLElement *safety_xml = config->FirstChildElement("safety_controller");
   if (safety_xml)
   {
     joint.safety.reset(new JointSafety());
     if (!parseJointSafety(*joint.safety, safety_xml))
     {
-      //logError("Could not parse safety element for joint [%s]", joint.name.c_str());
       joint.safety.reset();
       return false;
     }
   }
 
   // Get calibration
-  TiXmlElement *calibration_xml = config->FirstChildElement("calibration");
+  tinyxml2::XMLElement *calibration_xml = config->FirstChildElement("calibration");
   if (calibration_xml)
   {
     joint.calibration.reset(new JointCalibration());
     if (!parseJointCalibration(*joint.calibration, calibration_xml))
     {
-      //logError("Could not parse calibration element for joint  [%s]", joint.name.c_str());
       joint.calibration.reset();
       return false;
     }
   }
 
   // Get Joint Mimic
-  TiXmlElement *mimic_xml = config->FirstChildElement("mimic");
+  tinyxml2::XMLElement *mimic_xml = config->FirstChildElement("mimic");
   if (mimic_xml)
   {
     joint.mimic.reset(new JointMimic());
     if (!parseJointMimic(*joint.mimic, mimic_xml))
     {
-      //logError("Could not parse mimic element for joint  [%s]", joint.name.c_str());
       joint.mimic.reset();
       return false;
     }
   }
 
   // Get Dynamics
-  TiXmlElement *prop_xml = config->FirstChildElement("dynamics");
+  tinyxml2::XMLElement *prop_xml = config->FirstChildElement("dynamics");
   if (prop_xml)
   {
     joint.dynamics.reset(new JointDynamics());
     if (!parseJointDynamics(*joint.dynamics, prop_xml))
     {
-      //logError("Could not parse joint_dynamics element for joint [%s]", joint.name.c_str());
       joint.dynamics.reset();
       return false;
     }
@@ -564,71 +575,71 @@ bool parseJoint(Joint &joint, TiXmlElement* config)
 
 
 /* exports */
-bool exportPose(Pose &pose, TiXmlElement* xml);
+bool exportPose(Pose &pose, tinyxml2::XMLElement* xml);
 
-bool exportJointDynamics(JointDynamics &jd, TiXmlElement* xml)
+bool exportJointDynamics(JointDynamics &jd, tinyxml2::XMLElement* xml)
 {
-  TiXmlElement *dynamics_xml = new TiXmlElement("dynamics");
-  dynamics_xml->SetAttribute("damping", urdf_export_helpers::values2str(jd.damping) );
-  dynamics_xml->SetAttribute("friction", urdf_export_helpers::values2str(jd.friction) );
+  tinyxml2::XMLElement *dynamics_xml = xml->GetDocument()->NewElement("dynamics");
+  dynamics_xml->SetAttribute("damping", urdf_export_helpers::values2str(jd.damping).c_str() );
+  dynamics_xml->SetAttribute("friction", urdf_export_helpers::values2str(jd.friction).c_str() );
   xml->LinkEndChild(dynamics_xml);
   return true;
 }
 
-bool exportJointLimits(JointLimits &jl, TiXmlElement* xml)
+bool exportJointLimits(JointLimits &jl, tinyxml2::XMLElement* xml)
 {
-  TiXmlElement *limit_xml = new TiXmlElement("limit");
-  limit_xml->SetAttribute("effort", urdf_export_helpers::values2str(jl.effort) );
-  limit_xml->SetAttribute("velocity", urdf_export_helpers::values2str(jl.velocity) );
-  limit_xml->SetAttribute("lower", urdf_export_helpers::values2str(jl.lower) );
-  limit_xml->SetAttribute("upper", urdf_export_helpers::values2str(jl.upper) );
+  tinyxml2::XMLElement *limit_xml = xml->GetDocument()->NewElement("limit");
+  limit_xml->SetAttribute("effort", urdf_export_helpers::values2str(jl.effort).c_str() );
+  limit_xml->SetAttribute("velocity", urdf_export_helpers::values2str(jl.velocity).c_str() );
+  limit_xml->SetAttribute("lower", urdf_export_helpers::values2str(jl.lower).c_str() );
+  limit_xml->SetAttribute("upper", urdf_export_helpers::values2str(jl.upper).c_str() );
   xml->LinkEndChild(limit_xml);
   return true;
 }
 
-bool exportJointSafety(JointSafety &js, TiXmlElement* xml)
+bool exportJointSafety(JointSafety &js, tinyxml2::XMLElement* xml)
 {
-  TiXmlElement *safety_xml = new TiXmlElement("safety_controller");
-  safety_xml->SetAttribute("k_position", urdf_export_helpers::values2str(js.k_position) );
-  safety_xml->SetAttribute("k_velocity", urdf_export_helpers::values2str(js.k_velocity) );
-  safety_xml->SetAttribute("soft_lower_limit", urdf_export_helpers::values2str(js.soft_lower_limit) );
-  safety_xml->SetAttribute("soft_upper_limit", urdf_export_helpers::values2str(js.soft_upper_limit) );
+  tinyxml2::XMLElement *safety_xml = xml->GetDocument()->NewElement("safety_controller");
+  safety_xml->SetAttribute("k_position", urdf_export_helpers::values2str(js.k_position).c_str() );
+  safety_xml->SetAttribute("k_velocity", urdf_export_helpers::values2str(js.k_velocity).c_str() );
+  safety_xml->SetAttribute("soft_lower_limit", urdf_export_helpers::values2str(js.soft_lower_limit).c_str() );
+  safety_xml->SetAttribute("soft_upper_limit", urdf_export_helpers::values2str(js.soft_upper_limit).c_str() );
   xml->LinkEndChild(safety_xml);
   return true;
 }
 
-bool exportJointCalibration(JointCalibration &jc, TiXmlElement* xml)
+bool exportJointCalibration(JointCalibration &jc, tinyxml2::XMLElement* xml)
 {
   if (jc.falling || jc.rising)
   {
-    TiXmlElement *calibration_xml = new TiXmlElement("calibration");
+    tinyxml2::XMLElement *calibration_xml = xml->GetDocument()->NewElement("calibration");
     if (jc.falling)
-      calibration_xml->SetAttribute("falling", urdf_export_helpers::values2str(*jc.falling) );
+      calibration_xml->SetAttribute("falling", urdf_export_helpers::values2str(*jc.falling).c_str() );
     if (jc.rising)
-      calibration_xml->SetAttribute("rising", urdf_export_helpers::values2str(*jc.rising) );
+      calibration_xml->SetAttribute("rising", urdf_export_helpers::values2str(*jc.rising).c_str() );
     //calibration_xml->SetAttribute("reference_position", urdf_export_helpers::values2str(jc.reference_position) );
     xml->LinkEndChild(calibration_xml);
   }
   return true;
 }
 
-bool exportJointMimic(JointMimic &jm, TiXmlElement* xml)
+bool exportJointMimic(JointMimic &jm, tinyxml2::XMLElement* xml)
 {
   if (!jm.joint_name.empty())
   {
-    TiXmlElement *mimic_xml = new TiXmlElement("mimic");
-    mimic_xml->SetAttribute("offset", urdf_export_helpers::values2str(jm.offset) );
-    mimic_xml->SetAttribute("multiplier", urdf_export_helpers::values2str(jm.multiplier) );
-    mimic_xml->SetAttribute("joint", jm.joint_name );
+    tinyxml2::XMLElement *mimic_xml = xml->GetDocument()->NewElement("mimic");
+    mimic_xml->SetAttribute("offset", urdf_export_helpers::values2str(jm.offset).c_str() );
+    mimic_xml->SetAttribute("multiplier", urdf_export_helpers::values2str(jm.multiplier).c_str() );
+    mimic_xml->SetAttribute("joint", jm.joint_name.c_str() );
     xml->LinkEndChild(mimic_xml);
   }
   return true;
 }
 
-bool exportJoint(Joint &joint, TiXmlElement* xml)
+bool exportJoint(Joint &joint, tinyxml2::XMLElement* xml)
 {
-  TiXmlElement * joint_xml = new TiXmlElement("joint");
-  joint_xml->SetAttribute("name", joint.name);
+  tinyxml2::XMLElement * joint_xml = xml->GetDocument()->NewElement("joint");
+  joint_xml->SetAttribute("name", joint.name.c_str());
   if (joint.type == urdf::Joint::PLANAR)
     joint_xml->SetAttribute("type", "planar");
   else if (joint.type == urdf::Joint::FLOATING)
@@ -642,24 +653,23 @@ bool exportJoint(Joint &joint, TiXmlElement* xml)
   else if (joint.type == urdf::Joint::FIXED)
     joint_xml->SetAttribute("type", "fixed");
   else
-    //logError("ERROR:  Joint [%s] type [%d] is not a defined type.\n",joint.name.c_str(), joint.type);
 
   // origin
   exportPose(joint.parent_to_joint_origin_transform, joint_xml);
 
   // axis
-  TiXmlElement * axis_xml = new TiXmlElement("axis");
-  axis_xml->SetAttribute("xyz", urdf_export_helpers::values2str(joint.axis));
+  tinyxml2::XMLElement * axis_xml = xml->GetDocument()->NewElement("axis");
+  axis_xml->SetAttribute("xyz", urdf_export_helpers::values2str(joint.axis).c_str());
   joint_xml->LinkEndChild(axis_xml);
 
-  // parent 
-  TiXmlElement * parent_xml = new TiXmlElement("parent");
-  parent_xml->SetAttribute("link", joint.parent_link_name);
+  // parent
+  tinyxml2::XMLElement * parent_xml = xml->GetDocument()->NewElement("parent");
+  parent_xml->SetAttribute("link", joint.parent_link_name.c_str());
   joint_xml->LinkEndChild(parent_xml);
 
   // child
-  TiXmlElement * child_xml = new TiXmlElement("child");
-  child_xml->SetAttribute("link", joint.child_link_name);
+  tinyxml2::XMLElement * child_xml = xml->GetDocument()->NewElement("child");
+  child_xml->SetAttribute("link", joint.child_link_name.c_str());
   joint_xml->LinkEndChild(child_xml);
 
   if (joint.dynamics)
@@ -680,3 +690,5 @@ bool exportJoint(Joint &joint, TiXmlElement* xml)
 
 
 }
+
+#pragma warning(pop)
