@@ -26,14 +26,14 @@
 #include "sdf/Root.hh"
 #include "sdf/World.hh"
 #include "sdf/Filesystem.hh"
-#include "test_config.h"
+
+#include "test_config.hh"
 
 //////////////////////////////////////////////////
 TEST(ExplicitlySetInFile, EmptyRoadSphCoords)
 {
-  const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "empty_road_sph_coords.sdf");
+  const auto testFile =
+    sdf::testing::TestFile("sdf", "empty_road_sph_coords.sdf");
 
   sdf::Root root;
   sdf::Errors errors = root.Load(testFile);
@@ -109,9 +109,8 @@ TEST(ExplicitlySetInFile, EmptyRoadSphCoords)
 //////////////////////////////////////////////////
 TEST(ExplicitlySetInFile, EmptyAxis)
 {
-  const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "empty_axis.sdf");
+  const auto testFile =
+    sdf::testing::TestFile("sdf", "empty_axis.sdf");
 
   sdf::Root root;
   sdf::Errors errors = root.Load(testFile);
@@ -157,9 +156,8 @@ TEST(ExplicitlySetInFile, EmptyAxis)
 //////////////////////////////////////////////////
 TEST(ExplicitlySetInFile, ToString)
 {
-  const std::string testFile =
-    sdf::filesystem::append(PROJECT_SOURCE_PATH, "test", "sdf",
-        "empty_road_sph_coords.sdf");
+  const auto testFile =
+    sdf::testing::TestFile("sdf", "empty_road_sph_coords.sdf");
 
   sdf::Root root;
   sdf::Errors errors = root.Load(testFile);
@@ -198,7 +196,8 @@ TEST(ExplicitlySetInFile, ToString)
     << "      <heading_deg>0</heading_deg>\n"
     << "    </spherical_coordinates>\n"
     << "    <gravity>0 0 -9.8</gravity>\n"
-    << "    <magnetic_field>6e-06 2.3e-05 -4.2e-05</magnetic_field>\n"
+    << "    <magnetic_field>5.5645e-06 2.28758e-05 -4.23884e-05"
+    << "</magnetic_field>\n"
     << "    <atmosphere type='adiabatic'/>\n"
     << "    <physics type='ode'>\n"
     << "      <max_step_size>0.001</max_step_size>\n"
@@ -213,8 +212,10 @@ TEST(ExplicitlySetInFile, ToString)
     << "  </world>\n"
     << "</sdf>\n";
 
-  EXPECT_EQ(root.Element()->ToString(""), stream.str());
-  EXPECT_EQ(root.Element()->ToString("", true, false), stream.str());
+  sdf::PrintConfig config;
+  config.SetOutPrecision(6);
+  EXPECT_EQ(root.Element()->ToString("", config), stream.str());
+  EXPECT_EQ(root.Element()->ToString("", true, false, config), stream.str());
 
   stream.str(std::string());
   stream
@@ -232,7 +233,8 @@ TEST(ExplicitlySetInFile, ToString)
     << "      <heading_deg>0</heading_deg>\n"
     << "    </spherical_coordinates>\n"
     << "    <gravity>0 0 -9.8</gravity>\n"
-    << "    <magnetic_field>6e-06 2.3e-05 -4.2e-05</magnetic_field>\n"
+    << "    <magnetic_field>5.5645e-06 2.28758e-05 -4.23884e-05"
+    << "</magnetic_field>\n"
     << "    <atmosphere type='adiabatic'/>\n"
     << "    <physics name='default_physics' default='false' type='ode'>\n"
     << "      <max_step_size>0.001</max_step_size>\n"
@@ -247,5 +249,5 @@ TEST(ExplicitlySetInFile, ToString)
     << "  </world>\n"
     << "</sdf>\n";
 
-  EXPECT_EQ(root.Element()->ToString("", true, true), stream.str());
+  EXPECT_EQ(root.Element()->ToString("", true, true, config), stream.str());
 }
