@@ -27,7 +27,7 @@
 #include "sdf/Link.hh"
 #include "sdf/Model.hh"
 #include "sdf/Filesystem.hh"
-#include "test_config.h"
+#include "test_config.hh"
 
 //////////////////////////////////////////////////
 TEST(DOMWorld, LoadLights)
