@@ -18,7 +18,7 @@
 #include <gtest/gtest.h>
 #include <string>
 #include <gz/math/Color.hh>
-#include "sdf/sdf.hh"
+#include "sdf/parser.hh"
 
 #include "test_config.hh"
 
