@@ -17,8 +17,14 @@
 
 #include <string>
 #include <gtest/gtest.h>
-#include "sdf/sdf.hh"
+
+#include "sdf/Link.hh"
+#include "sdf/Material.hh"
+#include "sdf/Model.hh"
 #include "sdf/Pbr.hh"
+#include "sdf/parser.hh"
+#include "sdf/Root.hh"
+#include "sdf/Visual.hh"
 
 #include "test_config.hh"
 
@@ -41,7 +47,7 @@ TEST(Material, PbrDOM)
   ASSERT_NE(nullptr, link);
   EXPECT_EQ("link", link->Name());
 
-  // checkt visual materials
+  // check visual materials
   EXPECT_EQ(3u, link->VisualCount());
 
   // visual metal workflow
