@@ -20,7 +20,15 @@
 
 #include <gtest/gtest.h>
 
-#include "sdf/sdf.hh"
+#include "sdf/Collision.hh"
+#include "sdf/Geometry.hh"
+#include "sdf/Heightmap.hh"
+#include "sdf/Link.hh"
+#include "sdf/Model.hh"
+#include "sdf/parser.hh"
+#include "sdf/Root.hh"
+#include "sdf/Visual.hh"
+#include "sdf/World.hh"
 
 #include "test_config.hh"
 
