@@ -25,7 +25,7 @@
 #include "sdf/Model.hh"
 #include "sdf/Root.hh"
 #include "sdf/World.hh"
-#include "test_config.h"
+#include "test_config.hh"
 #include "test_utils.hh"
 
 //////////////////////////////////////////////////
@@ -157,7 +157,7 @@ TEST(DOMWorld, Load)
 TEST(DOMWorld, LoadModelFrameSameName)
 {
   const std::string testFile =
-    sdf::testing::TestFile("sdf", "world_model_frame_same_name.sdf");
+    sdf::testing::TestFile("sdf", "world_model_frame_same_name_1_6.sdf");
 
   // Load the SDF file
   sdf::Root root;
@@ -227,6 +227,22 @@ TEST(DOMWorld, LoadModelFrameSameName)
   EXPECT_EQ(Pose(0, -2, 3, 0, 0, 0), pose);
 }
 
+/////////////////////////////////////////////////
+TEST(DOMWorld, LoadModelFrameSameName_1_7)
+{
+  const std::string testFile =
+    sdf::testing::TestFile("sdf", "world_model_frame_same_name.sdf");
+
+  // Load the SDF file
+  sdf::Root root;
+  auto errors = root.Load(testFile);
+  for (auto e : errors)
+    std::cout << e << std::endl;
+  EXPECT_FALSE(errors.empty());
+  EXPECT_EQ(10u, errors.size());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::DUPLICATE_NAME);
+}
+
 /////////////////////////////////////////////////
 TEST(DOMWorld, NestedModels)
 {
